@@ -306,11 +306,13 @@ on_conf_save_btn_clicked               (GtkButton       *button,
                                         gpointer         user_data)
 {
   int old_rotation = pref.rotate_ccw;
+  int old_strategy = pref.sort_order;
   parse_config(GTK_WIDGET(button));
-  if(old_rotation != pref.rotate_ccw) {
-    toggle_rotation_direction();
-  }
   save_config();
+  if(old_rotation != pref.rotate_ccw)
+    toggle_rotation_direction();
+  if(old_strategy != pref.sort_order)
+    set_sort_strategy();
   gtk_widget_destroy(lookup_widget(GTK_WIDGET(button), CONFIG_WINDOW_NAME));
 }
 
@@ -490,7 +492,7 @@ void
 on_goto_page_activate                  (GtkMenuItem     *menu_item,
 					gpointer         user_data)
 {
-  goto_page(MainWindow);
+  goto_page();
 }
 
 void
